Setting the stage
=================

How to read this documentation
-------------------------------
Welcome to the spatial-model-editor (SME)!
This documentation is divided into three main parts. Of those, the 'Getting started' section is the most important one that every new user should work through. It will teach you how to create a new model in SME, and you will become familiar with all important functions the software has to offer along the way.

Secondly, there is a library of example models ready to run under 'Example models'. Once you are done with the 'Getting-started' section, you can look through those to get some experience with using SME. They have been selected to roughly cover all the different aspects of the software.

The third part, 'User guides', is a collection of more specialized articles that treat specific use cases. Have a look at them after you read the 'Getting started' section.

Finally, the 'Reference documentation' section contains more detailed information about the inner workings of SME. Treat this as a library in which you can look up specific information whenever you need it.

The 'Developer documentation' section is only relevant if you intend to contribute to SME's source code. It contains information about the code structure and how to run and add tests.


Installation
------------

No installation required, just download and run the executable for your operating system:

* |icon-linux|_ `linux <https://github.com/spatial-model-editor/spatial-model-editor/releases/latest/download/spatial-model-editor>`_
* |icon-osx|_ `macOS arm64 <https://github.com/ssciwr/sme-osx-arm64/releases/latest/download/spatial-model-editor.dmg>`_
* |icon-osx|_ `macOS intel <https://github.com/spatial-model-editor/spatial-model-editor/releases/latest/download/spatial-model-editor.dmg>`_
* |icon-windows|_ `windows <https://github.com/spatial-model-editor/spatial-model-editor/releases/latest/download/spatial-model-editor.exe>`_

.. tip::
   You may have to give permission before your operating system will run the executable:

   * Windows: "More info"->"Run anyway"
   * MacOS: right-click open
   * Linux: ``chmod +x spatial-model-editor``

.. note::
   On linux some additional system libraries are required that may not be installed by default. To install them:

   *  Fedora/RHEL/CentOS: ``sudo yum install xcb-util-image xcb-util-keysyms xcb-util-renderutil xcb-util-wm``

.. |icon-linux| image:: ../img/icon-linux.png
.. _icon-linux: https://github.com/spatial-model-editor/spatial-model-editor/releases/latest/download/spatial-model-editor

.. |icon-osx| image:: ../img/icon-osx.png
.. _icon-osx: https://github.com/spatial-model-editor/spatial-model-editor/releases/latest/download/spatial-model-editor.dmg

.. |icon-windows| image:: ../img/icon-windows.png
.. _icon-windows: https://github.com/spatial-model-editor/spatial-model-editor/releases/latest/download/spatial-model-editor.exe
